@@ -4,13 +4,12 @@ import importlib.metadata
 import itertools
 import sys
 
-from mdpeditor.explain import run_explain
-import mdpeditor.compile
-import mdpeditor.commandlineinterface.prompt
-import mdpeditor.commandlineinterface.arguments as arguments
-
 from rich.console import Console
-from rich import print
+
+import mdpeditor.commandlineinterface.arguments as arguments
+import mdpeditor.commandlineinterface.prompt
+import mdpeditor.compile
+import mdpeditor.parameterhelp.explain
 
 
 def run():
@@ -27,32 +26,29 @@ def run():
 
     command_line_arguments = arguments.get_command_line_arguments(version)
 
-    if command_line_arguments.command == "compile":
-
-        output_string = mdpeditor.compile.run_compile(
-            command_line_arguments.compile, command_line_arguments.merge_right,
-            command_line_arguments.full_mdp)
-
-        if (not command_line_arguments.compile
-                or command_line_arguments.compile[0].strip() == "help"):
-            console.print(output_string)
-            sys.exit()
-
-        mdpeditor.compile.print_annotated_output(console, output_string,
-                                                 version, sys.argv,
-                                                 command_line_arguments.output)
-
-        sys.exit()
-
-    if command_line_arguments.command == "explain":
+    if command_line_arguments.explain:
         try:
-            output_string = run_explain(command_line_arguments.explain)
+            output_string = mdpeditor.parameterhelp.explain.run_explain(
+                command_line_arguments.explain)
             console.print(output_string)
         except SystemExit as e:
             console.print(e.__str__())
             raise SystemExit("")
         sys.exit()
 
-    if not command_line_arguments.command:
+    if not command_line_arguments.compile:
         mdpeditor.commandlineinterface.prompt.run_interactive_prompt(
             console, version)
+        sys.exit()
+
+    output_string = mdpeditor.compile.run_compile(
+        command_line_arguments.compile, command_line_arguments.merge_right,
+        command_line_arguments.full_mdp)
+
+    if (command_line_arguments.compile[0].strip() == "help"):
+        console.print(output_string)
+        sys.exit()
+
+    mdpeditor.compile.print_annotated_output(console, output_string, version,
+                                             sys.argv,
+                                             command_line_arguments.output)
